@@ -52,5 +52,9 @@ class ProcManager(EnvAble, ConfAble):
         for i in self._isolates.values():
             i.process.terminate()
 
+    @property
+    def isolates(self):
+        return self._isolates
+
     def __repr__(self):
         return f"{self.__class__.__name__}"
