@@ -11,7 +11,7 @@ from importlib.abc import FileLoader
 from importlib.util import spec_from_loader, module_from_spec
 from multiprocessing import Queue
 from pathlib import Path
-from typing import Any, Type, TypeVar, Generic, Callable, Coroutine, get_args, NewType, cast, Tuple
+from typing import Any, Type, TypeVar, Generic, Callable, Coroutine, get_args, NewType, cast, Tuple, TypeAlias
 from typing import Union, Dict, List
 
 import loguru
@@ -24,13 +24,13 @@ from web import settings
 JSON = Union[Dict[str, Any], List[Any], int, str, float, bool, Type[None]]
 TypeJSON = Union[Dict[str, 'JSON'], List['JSON'], int, str, float, bool, Type[None]]
 
-GenAsyncCall = Callable[[Any, ...], Coroutine[Any, Any, Any]]
+GenAsyncCall: TypeAlias = Callable[[...], Coroutine[Any, Any, Any]]
 
-GenPerformCall = list[Coroutine[Any, Any, Any] | Coroutine[Any, Any, None]]
+GenPerformCall: TypeAlias = list[Coroutine[Any, Any, Any] | Coroutine[Any, Any, None]]
 
-GenConfig = TypeVar("GenConfig", bound=BaseModel)
+GenConfig: TypeAlias = TypeVar("GenConfig", bound=BaseModel)
 
-DtoType = TypeVar("DtoType", bound=BaseModel)
+DtoType: TypeAlias = TypeVar("DtoType", bound=BaseModel)
 
 
 # --------------------------------------------------MESSAGING TYPES-----------------------------------------------------
@@ -674,14 +674,18 @@ class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, me
 
     async def back_task(self,
                         target: BackTaskTarget,
-                        args: List[Any] = [],
-                        kwargs: Dict[str, Any] = {},
+                        args=None,
+                        kwargs=None,
                         trigger: BackTaskTrigger = None,
                         exec_type: str = "default",
                         on_error: BackTaskCallback = None,
                         on_complete: BackTaskCallback = None,
                         need_result: bool = False
                         ) -> TaskReturnEvent | None:
+        if args is None:
+            args = []
+        if kwargs is None:
+            kwargs = {}
         raise NotImplementedError
 
     async def new_rt(self, writer: RtWriter,
@@ -733,10 +737,8 @@ class Environment(ConfAble, AppNameAble, ChanAble, SharedStateAble):
                 self._resources.append(res)
 
     async def init(self):
-        # TODO CHEAT IS NEED?
-        # cheat(self, AppNameAble, self.app_name)
-        # cheat(self, ConfAble, self.conf)
-        # cheat(self, EnvAble, self)
+        cheat(self, AppNameAble, self.app_name)
+        cheat(self, ChanAble, self.channel)
         for res in self._resources:
             cheat(res, AppNameAble, self.app_name)
             cheat(res, ConfAble, self.conf)
@@ -774,9 +776,15 @@ class RtWriter(Generic[GenRtMessage]):
     message_class: GenRtMessage
     last_index: int = 0
     obj: Any
+    on_disconnect: List[GenAsyncCall] = None
 
     def __init__(self, obj: Any):
         self.obj = obj
+        self.on_disconnect = []
+
+    def on_close(self):
+        for task in self.on_disconnect:
+            asyncio.create_task(task())
 
     async def write(self, message: GenIMessage) -> None:
         raise NotImplementedError
@@ -784,9 +792,12 @@ class RtWriter(Generic[GenRtMessage]):
     async def freeze(self):
         raise NotImplementedError
 
-    async def run(self, on_disconnect: Callable):
+    def with_lost_callback(self, on_disconnect: GenAsyncCall) -> RtWriter:
+        self.on_disconnect.append(on_disconnect)
+        return self
+
+    async def run(self):
         await self.freeze()
-        await on_disconnect()
 
     async def close(self, *args, **kwargs):
         raise NotImplementedError
