@@ -26,11 +26,26 @@ from sanic.router import Router
 from web import settings
 from web.errors.app import ValidationError, ApplicationError
 from web.kernel.transport import Transport
-from web.kernel.types import DtoType
+from web.kernel.types import DtoType, ConfAble
 from web.kernel.types import Plugin, GenAsyncCall, ITransport
+from web.trend.rest.utils.openapi_gen import add_openapi
 from web.trend.rest.utils.openapi_spec import add_openapi_spec
 
 
+class ServingPaths(PdModel):
+    uri: str
+    path: str
+    route: bool = False
+
+
+SanicStaticServing = dict[str, list[ServingPaths]] | None
+
+
+class RouterConf(PdModel):
+    openapi_filepath: str | None
+    serving: SanicStaticServing
+
+
 @dataclass
 class PlugRouteConf:
     route: str
@@ -161,7 +176,7 @@ class CustomRequestHandler(ABC):
         return f
 
 
-class CustomRouter(Router):
+class CustomRouter(Router, ConfAble[RouterConf]):
     _router_conf: Dict
     open_api: bool
 
@@ -173,12 +188,11 @@ class CustomRouter(Router):
         self.open_api = open_api
 
     @classmethod
-    def set_serving_config(cls, sanic: Sanic, config, root_path="applied_files"):
+    def set_serving_config(cls, sanic: Sanic, config):
         """Configure serving static files"""
         if not hasattr(config, 'serving') or not config.serving:
             return
-        for dir_name, serv in config.serving.items():
-            target = os.path.join(root_path, dir_name)
+        for target, serv in config.serving.items():
             if not os.path.exists(target):
                 os.makedirs(target, exist_ok=True)
             for serv_path in serv:
@@ -262,6 +276,20 @@ class CustomRouter(Router):
                             version_prefix=version_prefix
                         )
 
+        try:
+            if self.conf:
+                self.set_serving_config(self.ctx.app, self.conf)
+
+                if hasattr(self.conf, "openapi_filepath") and self.conf.openapi_filepath:
+                    self.ctx.app.config.SWAGGER_UI_CONFIGURATION = {
+                        "docExpansion": 'none'
+                    }
+                    add_openapi(self.ctx.app, self.conf.openapi_filepath)
+                else:
+                    self.ctx.app.config.OAS = False
+        except RuntimeError:
+            pass
+
 
 class StatusCodes:
     APPLICATION_CODE = 409
